/**********************************************************************

Audacity: A Digital Audio Editor

GUISettings.h

Paul Licameli
   Moved a constant here from Envelope.h where it did not belong
   Define the key string in one place here too

**********************************************************************/
#ifndef __AUDACITY_GUI_SETTINGS__
#define __AUDACITY_GUI_SETTINGS__

#define ENV_DB_KEY (wxT("/GUI/EnvdBRange"))
#define ENV_DB_RANGE 60

#endif
